/********************************************************************************
* Advanced Database Topics
* Dave Valentine
* System Catalog View
*
* Part I - Search Columns Demo Scripts
********************************************************************************/

USE AdventureWorks2012;
GO

/********************************************************************************
* This script will find all columns that match the search criteria in all tables
* in the selected database
********************************************************************************/
DECLARE @ColumnName NVARCHAR(50) = N'Person';

SELECT SchemaName = s.name
	 , TableName =  t.name
	 , ColumnName = c.name 
FROM sys.columns c
INNER JOIN sys.tables t ON c.object_id = t.object_id
INNER JOIN sys.schemas s ON t.schema_id = s.schema_id
WHERE c.name LIKE '%' + @ColumnName + '%'
GO














/********************************************************************************
* This script will also find all columns that match the search criteria in all 
* objects in the selected database, including view and system tables.  This
* query uses built-in functions to resolve the Schema and Table names
********************************************************************************/
DECLARE @ColumnName NVARCHAR(50) = N'Person';
SELECT SchemaName = OBJECT_SCHEMA_NAME(c.object_id)
	 , TableName =  OBJECT_NAME(c.object_id)
	 , ColumnName = c.name 
FROM sys.columns c
WHERE c.name LIKE '%' + @ColumnName + '%';

GO








/********************************************************************************
* This script will also find all columns that match the search criteria in all 
* user defined tables in the selected database, because it uses the 
* OBJECTPROPERTY built in function.  This query uses built-in functions to 
* resolve the Schema and Table names.
********************************************************************************/
DECLARE @ColumnName NVARCHAR(50) = N'Person';

SELECT SchemaName = OBJECT_SCHEMA_NAME(c.object_id)
	 , TableName =  OBJECT_NAME(c.object_id)
	 , ColumnName = c.name 
FROM sys.columns c
WHERE c.name LIKE '%' + @ColumnName + '%'
AND OBJECTPROPERTY(c.object_id, 'IsUserTable') = 1;

-- https://docs.microsoft.com/en-us/sql/t-sql/functions/objectproperty-transact-sql
/********************************************************************************
* END Part I - Search Columns Demo Scripts
********************************************************************************/