/********************************************************************************
* Advanced Database Topics
* Dave Valentine
* System Catalog View
*
* PART IV - Search Indexes Demo Scripts
********************************************************************************/

USE AdventureWorks2012;
GO

/********************************************************************************
* This is the built-in function that returns the details for all indexes for
* for a specified table.
********************************************************************************/
exec sp_helpindex '[Production].[BillOfMaterials]'




/********************************************************************************
* This script will find all indexes for a given table that matches the search 
* criteria.  This script will return similar data to the built in function 
* sp_helpindex, however it will also return the included columns in an index
********************************************************************************/
DECLARE @TableName sysname = 'BillOfMaterials';
WITH IndexDetails AS (
	SELECT Type = i.type_desc
		 , PrimaryKey = CASE WHEN i.is_primary_key = 1 THEN 'True' ELSE 'False' END
		 , FileGroup = ds.name
		 , IndexName = i.name
		 , ColumnName = c.name
		 , ic.index_column_id
		 , ic.key_ordinal
		 , ic.is_included_column  		
		 , i.index_id
	FROM sys.indexes i
	INNER JOIN sys.data_spaces AS ds ON i.data_space_id = ds.data_space_id  
	INNER JOIN sys.index_columns ic ON i.object_id = ic.object_id AND i.index_id = ic.index_id  
	INNER JOIN sys.tables t ON i.object_id = t.object_id
	INNER JOIN sys.columns c ON i.object_id = c.object_id and ic.column_id = c.column_id 
	where t.name = @TableName
)
SELECT DISTINCT IndexName, Type, FileGroup, PrimaryKey
	 , IndexColumns = STUFF(( SELECT ', ' + ColumnName
							  FROM IndexDetails iid
							  WHERE iid.is_included_column = 0 and iid.index_id = id.index_id
							  ORDER BY iid.key_ordinal
							  FOR XML PATH('')),1,2,''
							  							  
					   )
	 , IncludedColumns = STUFF(( SELECT ', ' + ColumnName
							  FROM IndexDetails iid
							  WHERE iid.is_included_column = 1 and iid.index_id = id.index_id
							  FOR XML PATH('')),1,2,''
					   )	 
FROM IndexDetails id;

/********************************************************************************
* END PART IV - Search Indexes Demo Scripts
********************************************************************************/