/********************************************************************************
* Advanced Database Topics
* Dave Valentine
* System Catalog View
*
* PART V - Search Large Tables Demo Scripts
********************************************************************************/

USE AdventureWorks2012;
GO

/********************************************************************************
* This script is useful for determining the size of your tables and how quickly
* they are growing.  
********************************************************************************/
SELECT TableName = t.name
	 , IndexName = i.name
	 , CreatedDate = t.create_date
	 , ModifiedDate = t.modify_date
	 , RowCounts = SUM(p.rows)
	 , TotalPages = SUM(a.total_pages)
	 , UsedPages = SUM(a.used_pages)
	 , DataPages = SUM(a.data_pages)
	 , TotalSpaceMB = (SUM(a.total_pages) * 8) / 1024
	 , UsedSpaceMB = (SUM(a.used_pages) * 8) / 1024
	 , DataSpaceMB = (SUM(a.data_pages) * 8) / 1024
FROM  sys.tables t
INNER JOIN sys.indexes i ON t.object_id = i.object_id
INNER JOIN sys.partitions p ON i.object_id = p.object_id AND i.index_id = p.index_id
INNER JOIN sys.allocation_units a ON p.partition_id = a.container_id
WHERE i.index_id <= 1
GROUP BY  t.name, i.object_id, i.index_id, i.name, t.create_date, t.modify_date
ORDER BY RowCounts desc


/********************************************************************************
* END PART V - Search Large Tables Demo Scripts
********************************************************************************/