/********************************************************************************
* Advanced Database Topics
* Dave Valentine
* Dynamic Management Views
*
* PART I  Reviewing Query Plans Demo Scripts
********************************************************************************/

USE AdventureWorks2012;
GO

/********************************************************************************
* This script uses a few DMVs to return what queries have been processed
* and the Query Plans that have been cached.
* Query: cached_plans, query_stats, sql_text, query_plan
********************************************************************************/



/********************************************************************************
* This script uses a few DMVs to return what queries have been processed
* and the Query Plans that have been cached.
********************************************************************************/
SELECT ExecutionCount = cplan.usecounts
     , Type = cplan.objtype
     , QueryText = qtext.text
     , QueryPlan = qplan.query_plan
FROM sys.dm_exec_cached_plans AS cplan
CROSS APPLY sys.dm_exec_sql_text(plan_handle) AS qtext
CROSS APPLY sys.dm_exec_query_plan(plan_handle) AS qplan
ORDER BY cplan.usecounts DESC;


/********************************************************************************
*        !!!!!!!!!!!!!! CAUTION USING THIS SCRIPT !!!!!!!!!!!!!!!!!!!!
********************************************************************************/
/********************************************************************************
* This script will clear the query plan cache, this should not be executed in 
* production as this will force production to rebuild every plan as the queries
* are executed.
*
* Being this is demoland, we are going to use it to remove the excess plans.
********************************************************************************/
DBCC FREEPROCCACHE;
GO
/********************************************************************************
*        !!!!!!!!!!!!!! CAUTION USING THIS SCRIPT !!!!!!!!!!!!!!!!!!!!
********************************************************************************/



/********************************************************************************
* Running the same script again, we can see the cache is empty
********************************************************************************/
SELECT ExecutionCount = cplan.usecounts
     , Type = cplan.objtype
     , QueryText = qtext.text
     , QueryPlan = qplan.query_plan
FROM sys.dm_exec_cached_plans AS cplan
CROSS APPLY sys.dm_exec_sql_text(plan_handle) AS qtext
CROSS APPLY sys.dm_exec_query_plan(plan_handle) AS qplan
ORDER BY cplan.usecounts DESC;



/********************************************************************************
* Lets run a simple script to generate a query plan
********************************************************************************/
SELECT BOMLevel
     , ComponentID
     , StartDate
     , EndDate
FROM Production.BillOfMaterials
WHERE BOMLevel = 1;

/********************************************************************************
* Running the Query Plan script again, we can see the previous query that was 
* executed.  We can review the execution plan.
********************************************************************************/
SELECT ExecutionCount = cplan.usecounts
     , Type = cplan.objtype
     , QueryText = qtext.text
     , QueryPlan = qplan.query_plan
FROM sys.dm_exec_cached_plans AS cplan
CROSS APPLY sys.dm_exec_sql_text(plan_handle) AS qtext
CROSS APPLY sys.dm_exec_query_plan(plan_handle) AS qplan
ORDER BY cplan.usecounts DESC;


GO


/********************************************************************************
* So far we have seen Prepared and Adhoc types, building and executing a
* will generate a new type called proc.
********************************************************************************/
CREATE PROCEDURE dbo.getBillOfMaterials_BomLevel (@BOMLevel INT)
AS
BEGIN
    SELECT BOMLevel
         , ComponentID
         , StartDate
         , EndDate
    FROM Production.BillOfMaterials
    WHERE BOMLevel = @BOMLevel;
END;

GO

-- Execute the procedure 10 times
EXEC dbo.getBillOfMaterials_BomLevel @BOMLevel = 1
GO 10



/********************************************************************************
* Running the Query Plan script again, we can see Proc type along with the Query
* text of the procedure and the Execution Plan
********************************************************************************/
SELECT ExecutionCount = cplan.usecounts
     , Type = cplan.objtype
     , QueryText = qtext.text
     , QueryPlan = qplan.query_plan
FROM sys.dm_exec_cached_plans AS cplan
CROSS APPLY sys.dm_exec_sql_text(plan_handle) AS qtext
CROSS APPLY sys.dm_exec_query_plan(plan_handle) AS qplan
ORDER BY cplan.usecounts DESC;

/********************************************************************************
* END PART I  Reviewing Query Plans Demo Scripts
********************************************************************************/