/********************************************************************************
* Advanced Database Topics
* Dave Valentine
* Dynamic Management Views
*
* PART II  Execution Times Demo Scripts
* This script was originaly written by Tim Ford, the script can be found
* https://www.itprotoday.com/sql-server/estimate-when-long-running-sql-processes-will-finish
********************************************************************************/

USE AdventureWorks2012;
GO

/********************************************************************************
* This is one of my favorite scripts!
*
* If you have ever had a scenario where a database is being restored, backed-up,
* recovering, or some other scenarios where the database is down.  Then to make
* matters worse everyone wants an estimate on when the database will be 
* available, this is your script.
*
* This script utilizes the exec requests and SQL text DMVs to give you a 
* detailed view of running processes, including estimated completion times.
* We will execute this while we are restoring a database so we can see results. 
********************************************************************************/
SELECT dmreq.session_id
     , dmreq.percent_complete
     , elapsed_seconds = dmreq.total_elapsed_time / 1000
     , dmreq.wait_type
     , dmreq.wait_time
     , dmreq.last_wait_type
     , est_complete_time = DATEADD(s, 100 / ((dmreq.percent_complete) / (dmreq.total_elapsed_time / 1000)), dmreq.start_time)
     , batch_text = dmsql.text     
FROM sys.dm_exec_requests AS dmreq
CROSS APPLY sys.dm_exec_sql_text(dmreq.sql_handle) AS dmsql
WHERE dmreq.percent_complete > 0
      AND dmreq.session_id <> @@spid;





/********************************************************************************
* END PART II  Execution Times Demo Scripts
********************************************************************************/
