/********************************************************************************
* Advanced Database Topics
* Dave Valentine
* Indexing
*
* PART III  Indexing XML Demo Scripts
********************************************************************************/

USE AdventureWorks2012;
GO

SET STATISTICS IO ON;

--Cleanup from previous Demos and Testing.
--DROP INDEX IX_SalesOrderDetail_ProductIDOrderQty_ColumnStore ON Sales.SalesOrderDetail 
--DROP INDEX IX_SalesOrderDetail_ProductIDOrderQty ON Sales.SalesOrderDetail 


/***********************************************************************************
* Lets start by taking a look at the execution plan for a simple aggregate query
***********************************************************************************/
SELECT ProductID,SUM(OrderQty)
FROM Sales.SalesOrderDetail 
GROUP BY ProductId;




/***********************************************************************************
* Lets create a column store COLUMNSTORE INDEX on the table
***********************************************************************************/
CREATE COLUMNSTORE INDEX IX_SalesOrderDetail_ProductIDOrderQty_ColumnStore
ON Sales.SalesOrderDetail (ProductId,OrderQty);

/***********************************************************************************
* Lets check to see if the column store COLUMNSTORE INDEX on the table
***********************************************************************************/
SELECT ProductID,SUM(OrderQty)
FROM Sales.SalesOrderDetail 
GROUP BY ProductId;



/***********************************************************************************
* Lets create a NON CLUSTERED INDEX on the table
***********************************************************************************/
CREATE INDEX IX_SalesOrderDetail_ProductIDOrderQty
ON Sales.SalesOrderDetail (ProductId,OrderQty);


/***********************************************************************************
* Lets use the compare the two indexes.
***********************************************************************************/
SELECT TableName = t.name
	 , IndexName = i.name
	 , TotalPages = SUM(a.total_pages)
	 , TotalSpaceKB = (SUM(a.total_pages) * 8) 	 
FROM  sys.tables t
INNER JOIN sys.indexes i ON t.object_id = i.object_id
INNER JOIN sys.partitions p ON i.object_id = p.object_id AND i.index_id = p.index_id
INNER JOIN sys.allocation_units a ON p.partition_id = a.container_id
WHERE i.name like 'IX_SalesOrderDetail_ProductIDOrderQty%'	
GROUP BY  t.name, i.object_id, i.index_id, i.name, t.create_date, t.modify_date
ORDER BY TableName desc
GO

/********************************************************************************
* END PART III  Indexing XML Demo Scripts
********************************************************************************/

