/********************************************************************************
* Advanced Database Topics
* Dave Valentine
* Indexing
*
* PART IV  Index Utilzation
********************************************************************************/

USE AdventureWorks2012;
GO
/********************************************************************************
* This script uses an index usage stats DMV to return how many times the index 
* has been used via scan, seek, lookups, and updates.
********************************************************************************/
SELECT ObjectName = o.name
     , IndexName = i.name
     , UserSeeks = user_seeks
     , UserScans = user_scans
     , UserLookups = user_lookups
     , UserUpdates = user_updates
FROM sys.dm_db_index_usage_stats dmius
INNER JOIN sys.indexes i ON  i.object_id = dmius.object_id AND i.index_id = dmius.index_id
INNER JOIN sys.objects o ON o.object_id = dmius.object_id
WHERE  OBJECTPROPERTY(dmius.object_id, 'IsUserTable') = 1;

/********************************************************************************
* This script a the missing index DMVs to return indexes that are possibility 
* missing.  Take caution with these recommendations as they not have the 
* positive impact that is expected.  Note the Impact and SeekCount columns.
********************************************************************************/
SELECT DatabaseName = d.name
     , TableName = dmmid.statement
     , EqualityColumns = dmmid.equality_columns
     , InequalityColumns = dmmid.inequality_columns
     , IncludeColumns = dmmid.included_columns
     , LastSeek = dmmigs.last_user_seek
     , AvgCost = dmmigs.avg_total_user_cost
     , Impact = dmmigs.avg_user_impact
     , SeekCount = dmmigs.user_seeks	 
FROM sys.dm_db_missing_index_groups dmmig
INNER JOIN sys.dm_db_missing_index_group_stats dmmigs ON dmmigs.group_handle = dmmig.index_group_handle
INNER JOIN sys.dm_db_missing_index_details dmmid ON dmmig.index_handle = dmmid.index_handle
INNER JOIN sys.databases d ON d.database_id = dmmid.database_id;
--AND d.name = '';


/********************************************************************************
* Brent Ozars Index Blitz script can be found in the first responder scripts. 
* This script is very handy as there are descriptions as well as possible 
* scripts.  Here again caution with the recommendations as they may not have the 
* positive impact that is expected.
********************************************************************************/
exec sp_BlitzIndex @ThresholdMB = 0;




/********************************************************************************
* END PART IV  Index Utilzation
********************************************************************************/

